@@ -8,6 +8,8 @@ use std::{
     process::Command,
 };
 
+use terminal_size::{terminal_size, Width};
+
 use prettytable::{
     cell,
     format::{LinePosition, LineSeparator},
@@ -239,11 +241,37 @@ impl fmt::Display for Expression {
                 fmt.separator(LinePosition::Title, LineSeparator::new('═', '╪', '╞', '╡'));
                 fmt.separator(LinePosition::Intern, LineSeparator::new('─', '┼', '├', '┤'));
                 fmt.separator(LinePosition::Bottom, LineSeparator::new('─', '┴', '└', '┘'));
+
+                let width = match terminal_size() {
+                    Some((Width(width), _)) => Some(width as usize),
+                    _ => None,
+                };
+
                 for (key, val) in exprs {
-                    if let Self::Builtin(Builtin { help, .. }) = &val {
-                        t.add_row(row!(key, format!("{}", val), help));
-                    } else {
-                        t.add_row(row!(key, format!("{}", val)));
+                    match &val {
+                        Self::Builtin(Builtin { help, .. }) => {
+                            t.add_row(row!(
+                                key,
+                                format!("{}", val),
+                                match width {
+                                    Some(w) => textwrap::fill(help, w / 6),
+                                    None => help.to_string(),
+                                }
+                            ));
+                        }
+                        Self::Map(_) => {
+                            t.add_row(row!(key, format!("{}", val)));
+                        }
+                        _ => {
+                            let formatted = format!("{}", val);
+                            t.add_row(row!(
+                                key,
+                                match width {
+                                    Some(w) => textwrap::fill(&formatted, w / 5),
+                                    None => formatted,
+                                }
+                            ));
+                        }
                     }
                 }
                 write!(f, "{}", t)
